@@ -1,9 +1,9 @@
 /*
  * DMNTK - Decision Model and Notation Toolkit
  *
- * FEEL evaluator.
+ * MIT license
  *
- * Copyright 2018-2021 Dariusz Depta Engos Software <dariusz.depta@engos.software>
+ * Copyright (c) 2018-2021 Dariusz Depta Engos Software
  *
  * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
@@ -12,6 +12,22 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
  * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
  * SOFTWARE.
+ *
+ * Apache license, Version 2.0
+ *
+ * Copyright (c) 2018-2021 Dariusz Depta Engos Software
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 use crate::bifs;
@@ -2108,7 +2124,6 @@ fn eval_in_unary_greater_or_equal(left: &Value, right: &Value) -> Value {
 
 /// Evaluates function definition with positional parameters.
 fn eval_function_positional(scope: &Scope, arguments: &[Value], parameters: &[(Name, FeelType)], body: &FunctionBody, result_type: FeelType) -> Value {
-  println!("BBB: evaluate function positional");
   let mut ctx = FeelContext::default();
   for (i, (parameter_name, parameter_type)) in parameters.iter().enumerate() {
     if let Some(argument) = arguments.get(i) {
@@ -2122,7 +2137,6 @@ fn eval_function_positional(scope: &Scope, arguments: &[Value], parameters: &[(N
 
 /// Evaluates function definition with named parameters.
 fn eval_function_named(scope: &Scope, arguments: &Value, parameters: &[(Name, FeelType)], body: &FunctionBody, result_type: FeelType) -> Value {
-  println!("BBB: evaluate function named");
   let mut ctx = FeelContext::default();
   if let Value::NamedParameters(map) = arguments {
     for (parameter_name, parameter_type) in parameters {
